SqfliteLoggerDatabaseOpenEvent class abstract

Open db event

Inheritance
Available extensions

Properties

databaseId → int?
Database internal id, if successfully opened.
no setter
db → Database?
The resulting database on success
no setter
error → Object?
Set on failure
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String
Name of the command (insert/delete/update...) for display only.
no setterinherited
options → OpenDatabaseOptions?
The options used.
no setter
path → String?
Invoke arguments.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sw → Stopwatch?
Stopwatch. for performance testing.
no setterinherited

Methods

dump({void print(Object? object)?, bool? noStopwatch}) → void

Available on SqfliteLoggerEvent, provided by the SqfliteLoggerEventExt extension

dump event by lines
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited