SqfliteLoggerSqlCommandQuery class abstract

Event or batch operation query command.

Inheritance

Properties

arguments → Object?
Sql arguments.
no setterinherited
error → Object?
Set on failure
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String
Name of the command (insert/delete/update...) for display only.
no setterinherited
result → List<Map<String, Object?>>?
Optional result.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sql → String
Invoke arguments.
no setterinherited
type → SqliteSqlCommandType
The command type.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited